@@ -1,7 +1,7 @@
 package Config::IOD;
 
-our $DATE = '2015-03-18'; # DATE
-our $VERSION = '0.13'; # VERSION
+our $DATE = '2015-03-19'; # DATE
+our $VERSION = '0.14'; # VERSION
 
 use 5.010001;
 use strict;
@@ -47,7 +47,42 @@ sub _read_string {
             next LINE;
         }
 
+        # key line
+        if ($line =~ /^(\s*)([^=]+?)(\s*)=
+                      (\s*)(.*?)
+                      (\R?)\z/x) {
+            push @$res, [
+                'K',
+                $1, # COL_K_WS1
+                $2, # COL_K_KEY
+                $3, # COL_K_WS2
+                $4, # COL_K_WS3
+                $5, # COL_K_VALUE_RAW
+                $6, # COL_K_NL
+            ];
+            next LINE;
+        }
+
+        # section line
+        if ($line =~ /^(\s*)\[(\s*)(.+?)(\s*)\]
+                      (?: (\s*)([;#])(.*))?
+                      (\R?)\z/x) {
+            push @$res, [
+                'S',
+                $1, # COL_S_WS1
+                $2, # COL_S_WS2
+                $3, # COL_S_SECTION
+                $4, # COL_S_WS3
+                $5, # COL_S_WS4
+                $6, # COL_S_COMMENT_CHAR
+                $7, # COL_S_COMMENT
+                $8, # COL_S_NL
+            ];
+            next LINE;
+        }
+
         # directive line
+        my $line0 = $line;
         if ($line =~ s/$directive_re//) {
             push @$res, [
                 'D',
@@ -95,11 +130,18 @@ sub _read_string {
             } elsif ($directive eq 'merge') {
             } elsif ($directive eq 'noop') {
             } else {
-                $self->_err("Unknown directive '$directive'");
+                if ($self->{ignore_unknown_directive}) {
+                    # assume a regular comment
+                    $line = $line0;
+                    goto L1;
+                } else {
+                    $self->_err("Unknown directive '$directive'");
+                }
             }
             next LINE;
         }
 
+      L1:
         # comment line
         if ($line =~ /^(\s*)([;#])(.*?)
                       (\R?)\z/x) {
@@ -113,40 +155,6 @@ sub _read_string {
             next LINE;
         }
 
-        # section line
-        if ($line =~ /^(\s*)\[(\s*)(.+?)(\s*)\]
-                      (?: (\s*)([;#])(.*))?
-                      (\R?)\z/x) {
-            push @$res, [
-                'S',
-                $1, # COL_S_WS1
-                $2, # COL_S_WS2
-                $3, # COL_S_SECTION
-                $4, # COL_S_WS3
-                $5, # COL_S_WS4
-                $6, # COL_S_COMMENT_CHAR
-                $7, # COL_S_COMMENT
-                $8, # COL_S_NL
-            ];
-            next LINE;
-        }
-
-        # key line
-        if ($line =~ /^(\s*)([^=]+?)(\s*)=
-                      (\s*)(.*?)
-                      (\R?)\z/x) {
-            push @$res, [
-                'K',
-                $1, # COL_K_WS1
-                $2, # COL_K_KEY
-                $3, # COL_K_WS2
-                $4, # COL_K_WS3
-                $5, # COL_K_VALUE_RAW
-                $6, # COL_K_NL
-            ];
-            next LINE;
-        }
-
         $self->_err("Invalid syntax");
     }
 
@@ -175,7 +183,7 @@ Config::IOD - Read and write IOD configuration files
 
 =head1 VERSION
 
-This document describes version 0.13 of Config::IOD (from Perl distribution Config-IOD), released on 2015-03-18.
+This document describes version 0.14 of Config::IOD (from Perl distribution Config-IOD), released on 2015-03-19.
 
 =head1 SYNOPSIS
 
@@ -328,6 +336,11 @@ config file and force user to use JSON encoding or bracket to specify array:
  [section]
  a=[1,2]
 
+=head2 ignore_unknown_directive => bool (default: 0)
+
+If set to true, will not die if an unknown directive is encountered. It will
+simply be ignored as a regular comment.
+
 =head1 METHODS
 
 =head2 new(%attrs) => obj
